@@ -6,11 +6,6 @@ from toga.style.pack import Pack, COLUMN, ROW
 import styles
 import events
 
-
-def button_handler(widget):
-    print("hello")
-
-
 def build(app):
     layout = Layout()
     layout.styles = [styles]
@@ -18,7 +13,7 @@ def build(app):
     return layout.load('./example/layout.yaml')
 
 def main():
-    return toga.App('Calculator', 'org.beeware.helloworld', startup=build)
+    return toga.App('Example Layout App', 'org.ignaciocabeza.example_layout_app', startup=build)
 
 
 if __name__ == '__main__':
